@@ -1,5 +1,4 @@
-#!/usr/bin/env python
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 """ Generic Writer for File Contents """
 
 
@@ -34,7 +33,6 @@ class FileContentWriter(BaseObject):
             FileIO.write_json(data=file_data, file_path=file_path)
 
         elif file_ext in ['jpg', 'png']:
-            print (file_data)
             with open(file_path, 'wb') as f:
                 f.write(file_data)
 
